@@ -1,5 +1,5 @@
 /* example2.c --- Example code showing how to use punycode.
- * Copyright (C) 2002-2012 Simon Josefsson
+ * Copyright (C) 2002-2013 Simon Josefsson
  * Copyright (C) 2002  Adam M. Costello
  *
  * This file is part of GNU Libidn.
@@ -184,7 +184,8 @@ main (int argc, char **argv)
 
       /* Read the Punycode input string and convert to ASCII: */
 
-      fgets (input, ace_max_length + 2, stdin);
+      if (!fgets (input, ace_max_length + 2, stdin))
+	fail (io_error);
       if (ferror (stdin))
 	fail (io_error);
       if (feof (stdin))
